<script setup>
import { ref } from 'vue';
import { Inertia } from '@inertiajs/inertia';
import { Head, Link } from '@inertiajs/inertia-vue3';
import JetApplicationMark from '@/Jetstream/ApplicationMark.vue';
import JetBanner from '@/Jetstream/Banner.vue';
import JetDropdown from '@/Jetstream/Dropdown.vue';
import JetDropdownLink from '@/Jetstream/DropdownLink.vue';
import JetNavLink from '@/Jetstream/NavLink.vue';
import JetResponsiveNavLink from '@/Jetstream/ResponsiveNavLink.vue';
import Highcharts from 'highcharts';
import DK_Alert from '@/components/dk_Alert.vue';

defineProps({
    title: String,
});

const showingNavigationDropdown = ref(false);

const switchToTeam = (team) => {
    Inertia.put(route('current-team.update'), {
        team_id: team.id,
    }, {
        preserveState: false,
    });
};

const logout = () => {
    //router.post(route('logout'));

    axios.post('/logout')
        .then((response) => {
            //window.emitter.emit('changeLoaderStatus', true, 'orbit')
            window.location.href = window.location.origin;
        })
        .catch(error => {
            // Manejar el error de la solicitud
        });
};

</script>

<style>


/* ANIMATION-bounce STYLING */

.animate-bounce {
    animation: bounce 1s infinite;
}

@keyframes bounce {

    0%,
    100% {
        transform: translateY(-15%);
        animation-timing-function: cubic-bezier(0.8, 0, 1, 1);
    }

    50% {
        transform: translateY(0);
        animation-timing-function: cubic-bezier(0, 0, 0.2, 1);
    }
}

.rounded-drop {
    border-radius: 0 50% 50% 50%;
    transform: rotate(45deg) !important;
    transform-origin: left !important;
}

.text-drop {
    border-radius: 0 50% 50% 50%;
    transform: rotate(-45deg) !important;
    transform-origin: right !important;
}
</style>



<template>

    <DK_Alert :visibility="ComponentVisibility" @close="hideComponent" :title="ComponentTitle" :message="ComponentMessage" :width="ComponentWidth"></DK_Alert>

    <div>

        <Head :title="title" />

        <JetBanner />
        <loader-component></loader-component>
        <div style="min-height: 100vh !important">
            <nav class="border-0 bg-blue-navbar sticky drop-shadow-xl top-0 z-[110]">
                <!-- Primary Navigation Menu -->
                <div class="w-auto lg:px-6 px-4">
                    <div class="flex justify-between h-12">
                        <div class="flex">
                            <!-- Logo -->
                            <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('Water_GlobalView')" class="h-9 self-center mr-5 max-w-[6.5rem] lg:mr-6">
                        <JetApplicationMark />
                        </Link>

                            <!-- Navigation Links -->
                            <div class="mt-1 sm:-my-px flex">
                                <JetNavLink class="lg:px-6 lg:flex lg:px-4 hidden"
                                    
                                    onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('Water_GlobalView')" :active="route().current('Water_GlobalView')">
                                    {{ $t("general.Map") }}
                                </JetNavLink>
                            <JetNavLink class="lg:px-6 lg:flex lg:px-3 hidden"
                                
                                onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('Water_Devices')" :active="route().current('Water_Devices')">
                                {{ $t("general.Gateways") }}
                            </JetNavLink>
                            <template
                                v-if="$page.props.user.admin == 0 || $page.props.user.admin == 1 || $page.props.user.admin == 2">

                                <JetNavLink class="lg:px-6 lg:flex lg:px-4 hidden relative group"
                                    onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('alerts')" :active="route().current('alerts')">
                                    {{ $t("general.Alerts") }}
                                    <div v-bind:class="{ 'text-blue-navbar': this.getURL().indexOf('alerts') == -1, 'text-blue-link-navbar': this.getURL().indexOf('alerts') != -1 }"
                                        v-if="this.Alerts_badge != '0' && this.Alerts_badge != '9+'"
                                        class="animate-bounce inline-flex absolute top-1.5 leading-[10px] right-0.5 justify-center w-3 h-3 shadow-lg items-center text-[10px] font-bold bg-white rounded-drop">
                                        <a class="pl-[2px] pb-2 text-drop">{{ this.Alerts_badge }}</a></div>
                                    <div v-bind:class="{ 'text-blue-navbar': this.getURL().indexOf('alerts') == -1, 'text-blue-link-navbar': this.getURL().indexOf('alerts') != -1 }"
                                        v-if="this.Alerts_badge == '9+'"
                                        class="animate-bounce inline-flex absolute top-1.5 right-0.5 justify-center w-3 leading-[10px] h-3 shadow-lg items-center text-[10px] font-bold bg-white rounded-drop">
                                        <a class="pl-[2px] pb-2 text-drop">{{ this.Alerts_badge }}</a></div>
                                    <!--<span class="inline-flex items-center justify-center w-4 h-4 ml-2 text-xs font-semibold text-blue-800 bg-blue-200 rounded-full">
                                            {{this.Alerts_badge}}
                                        </span>
                                        <div v-if="this.Alerts_badge != '0' && this.Alerts_badge != '9+'" class="animate-bounce inline-flex absolute top-1 right-0.5 justify-center w-3.5 h-3.5 shadow-lg items-center text-[9px] pb-[2px] font-bold text-white-snow rounded-full">
                                            <i class="fa-solid fa-triangle-exclamation" style="font-size:0.75rem; color:rgba(224,191,52,1);"></i>
                                        </div>-->
                                </JetNavLink>

                                <JetNavLink class="lg:px-6 lg:flex lg:px-2 hidden"
                                    onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('Water_NetworkSimulation')" :active="route().current('Water_NetworkSimulation')">
                                    {{ $t("general.Network simulation") }}
                                </JetNavLink>

                            </template>

                            <!-- Settings Admin Dropdown -->
                            <div class="inline-flex items-center text-sm font-semibold leading-5 text-gray-200 focus:outline-none focus:text-white-snow transition ">
                                <JetDropdown align="left">
                                    <template #trigger>
                                        <button type="button"
                                            class="inline-flex items-center border-transparent border-gray-semilight text-sm font-medium hover:font-semibold hover:text-white-snow hover:border-b hover:bg-cyan-opa leading-5 text-gray-200 focus:outline-none focus:text-white-snow lg:px-6 lg:flex lg:px-4 hidden"
                                            style="height: 3rem;">
                                            {{ $t("general.Administration") }}
                                        </button>
                                    </template>
                                    <template #content>
                                        <JetDropdownLink class="text-white-snow" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('Water_EditGroup')"
                                            :active="route().current('Water_EditGroup')"
                                            >
                                            {{ $t("general.Manage network") }}
                                        </JetDropdownLink>
                                        <template v-if="$page.props.user.admin == 0 || $page.props.user.admin == 1">
                                            <JetDropdownLink class="text-white-snow" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('manageProfiles')"
                                            >
                                            {{ $t("general.Users") }}
                                            </JetDropdownLink>
                                        </template>
                                    </template>
                                </JetDropdown>
                            </div>
                        </div>
                    </div>

                    <JetDropdown align="right">
                        <!--<div class="grid place-content-center ml-6">-->

                        <!-- Settings Dropdown 
                        <div class="ml-3 relative">-->
                        
                            <template #trigger>
                                <div class="flex h-full items-center justify-center">
                                    <p class="inline-flex rounded-md items-center justify-center">
                                        <button type="button"
                                            class="items-center px-3 py-2 border border-transparent text-sm leading-4 font-medium rounded-md text-white-snow hover:drop-shadow-lg bg-cyan-opa active:drop-shadow-lg active:bg-cyan-opa focus:drop-shadow-lg focus:bg-cyan-opa focus:outline-none transition">
                                            <p class="font-bold hidden" style="display:inline-flex">
                                                {{ $page.props.user.name[0] }}</p>
                                        </button>
                                    </p>
                                </div>
                            </template>

                            <template #content>
                                <JetDropdownLink class="text-white-snow lg:hidden"                                
                                    onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('Water_GlobalView')">
                                    {{ $t("general.Map") }}
                                </JetDropdownLink>

                                <JetDropdownLink class="text-white-snow lg:hidden"
                                    
                                    onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('Water_Devices')">
                                    {{ $t("general.Gateways") }}
                                </JetDropdownLink>
                                <template
                                    v-if="$page.props.user.admin == 0 || $page.props.user.admin == 1 || $page.props.user.admin == 2">

                                    <JetDropdownLink class="text-white-snow lg:hidden" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('alerts')">
                                        {{ $t("general.Alerts") }}
                                    </JetDropdownLink>

                                    <JetDropdownLink class="text-white-snow select-none opacity-50 lg:hidden"
                                        onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('Water_NetworkSimulation')" :active="route().current('Water_NetworkSimulation')">
                                        {{ $t("general.Network simulation") }}
                                    </JetDropdownLink>

                                    <JetDropdownLink v-if="$page.props.user.admin != 2" class="text-white-snow lg:hidden"
                                        
                                        onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('manageProfiles')">
                                        {{ $t("general.Users") }}
                                    </JetDropdownLink>

                                </template>
                                <JetDropdownLink class="text-white-snow lg:hidden" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('Water_EditGroup')"
                                    :active="route().current('Water_EditGroup')">
                                    {{ $t("general.Manage network") }}
                                </JetDropdownLink>

                                <div class="my-0.5 mx-2 border-t border-white lg:hidden"></div>

                                <!-- Account Management -->

                                <!--<JetDropdownLink class="text-white-snow" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('profile.show')">
                                        {{$t("general.My profile")}}
                                    </JetDropdownLink>-->

                                <JetDropdownLink class="text-white-snow"
                                    onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('userProfile')">
                                    {{ $t("general.Edit User") }}
                                </JetDropdownLink>

                                <JetDropdownLink v-if="$page.props.user.admin == 0" class="text-white-snow"
                                    onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('routing')">
                                    {{ $t("general.Change group") }}
                                </JetDropdownLink>

                                <!--<JetDropdownLink class="text-white-snow hidden" v-if="$page.props.jetstream.hasApiFeatures && ($page.props.user.admin == 0 || $page.props.user.admin == 1)" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('api-tokens.index')">
                                        API Tokens
                                    </JetDropdownLink>-->

                                <!-- Admin Management -->
                                <!--<template v-if="$page.props.user.admin == 1">   
                                        <JetDropdownLink class="text-white-snow" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('manageProfiles')">
                                            Manage Profiles
                                        </JetDropdownLink>
                                    </template>-->

                                <!--<template v-if="$page.props.jetstream.hasTeamFeatures">-->

                                <!-- Team Settings -->
                                <!--<JetDropdownLink class="text-white-snow" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('teams.show', $page.props.user.current_team)">
                                            Team Settings
                                        </JetDropdownLink>

                                        <JetDropdownLink class="text-white-snow" v-if="$page.props.jetstream.canCreateTeams" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('teams.create')">
                                            Create New Team
                                        </JetDropdownLink>-->


                                <!-- Team Switcher -->

                                <!--<template v-for="team in $page.props.user.all_teams" :key="team.id">
                                            <form @submit.prevent="switchToTeam(team)">
                                                <JetDropdownLink as="button">
                                                    <div class="flex items-center">
                                                        <div class="text-white-snow">{{ team.name }} &nbsp; </div>                                                                
                                                        <svg 
                                                            v-if="team.id == $page.props.user.current_team_id"
                                                            xmlns="http://www.w3.org/2000/svg"
                                                            xmlns:xlink="http://www.w3.org/1999/xlink"
                                                            width="20px" height="20px" viewBox="0 0 24 24" version="1.1">
                                                            <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">
                                                                <polygon points="0 0 24 0 24 24 0 24"/>
                                                                <path d="M6.26193932,17.6476484 C5.90425297,18.0684559 5.27315905,18.1196257 4.85235158,17.7619393 C4.43154411,17.404253 4.38037434,16.773159 4.73806068,16.3523516 L13.2380607,6.35235158 C13.6013618,5.92493855 14.2451015,5.87991302 14.6643638,6.25259068 L19.1643638,10.2525907 C19.5771466,10.6195087 19.6143273,11.2515811 19.2474093,11.6643638 C18.8804913,12.0771466 18.2484189,12.1143273 17.8356362,11.7474093 L14.0997854,8.42665306 L6.26193932,17.6476484 Z" fill="#66c1e9" fill-rule="nonzero" transform="translate(11.999995, 12.000002) rotate(-180.000000) translate(-11.999995, -12.000002) "/>
                                                            </g>
                                                        </svg>
                                                    </div>
                                                </JetDropdownLink>
                                            </form>
                                        </template>
                                    </template>-->

                                <!-- Authentication -->
                                <form @submit.prevent="logout">
                                    <JetDropdownLink as="button">
                                        <div class="grid grid-cols-2 text-white-snow">
                                            <div class="whitespace-nowrap">{{ $t("general.Sign out") }}</div>
                                            <div class="justify-self-end">
                                                <p class="svg-icon svg-icon-primary svg-icon-2x">
                                                    <svg xmlns="http://www.w3.org/2000/svg"
                                                        xmlns:xlink="http://www.w3.org/1999/xlink" width="20px"
                                                        height="20px" viewBox="0 0 24 24" version="1.1">
                                                        <g stroke="none" stroke-width="1" fill="none"
                                                            fill-rule="evenodd">
                                                            <rect x="0" y="0" width="24" height="24" />
                                                            <path
                                                                d="M14.0069431,7.00607258 C13.4546584,7.00607258 13.0069431,6.55855153 13.0069431,6.00650634 C13.0069431,5.45446114 13.4546584,5.00694009 14.0069431,5.00694009 L15.0069431,5.00694009 C17.2160821,5.00694009 19.0069431,6.7970243 19.0069431,9.00520507 L19.0069431,15.001735 C19.0069431,17.2099158 17.2160821,19 15.0069431,19 L3.00694311,19 C0.797804106,19 -0.993056895,17.2099158 -0.993056895,15.001735 L-0.993056895,8.99826498 C-0.993056895,6.7900842 0.797804106,5 3.00694311,5 L4.00694793,5 C4.55923268,5 5.00694793,5.44752105 5.00694793,5.99956624 C5.00694793,6.55161144 4.55923268,6.99913249 4.00694793,6.99913249 L3.00694311,6.99913249 C1.90237361,6.99913249 1.00694311,7.89417459 1.00694311,8.99826498 L1.00694311,15.001735 C1.00694311,16.1058254 1.90237361,17.0008675 3.00694311,17.0008675 L15.0069431,17.0008675 C16.1115126,17.0008675 17.0069431,16.1058254 17.0069431,15.001735 L17.0069431,9.00520507 C17.0069431,7.90111468 16.1115126,7.00607258 15.0069431,7.00607258 L14.0069431,7.00607258 Z"
                                                                fill="#FFFAFA" fill-rule="nonzero"
                                                                transform="translate(9.006943, 12.000000) scale(-1, 1) rotate(-90.000000) translate(-9.006943, -12.000000) " />
                                                            <rect fill="#FFFAFA"
                                                                transform="translate(14.000000, 12.000000) rotate(-270.000000) translate(-14.000000, -12.000000) "
                                                                x="13" y="6" width="2" height="12" rx="1" />
                                                            <path
                                                                d="M21.7928932,9.79289322 C22.1834175,9.40236893 22.8165825,9.40236893 23.2071068,9.79289322 C23.5976311,10.1834175 23.5976311,10.8165825 23.2071068,11.2071068 L20.2071068,14.2071068 C19.8165825,14.5976311 19.1834175,14.5976311 18.7928932,14.2071068 L15.7928932,11.2071068 C15.4023689,10.8165825 15.4023689,10.1834175 15.7928932,9.79289322 C16.1834175,9.40236893 16.8165825,9.40236893 17.2071068,9.79289322 L19.5,12.0857864 L21.7928932,9.79289322 Z"
                                                                fill="#FFFAFA" fill-rule="nonzero"
                                                                transform="translate(19.500000, 12.000000) rotate(-90.000000) translate(-19.500000, -12.000000) " />
                                                        </g>
                                                    </svg>
                                                </p>
                                            </div>
                                        </div>
                                    </JetDropdownLink>
                                </form>
                            </template>
                            <!--</div>-->
                        </JetDropdown>
                    </div>
                </div>
            </nav>
            <!-- Page Content -->
            <main style="min-height: calc(100vh - 4.75rem);">
                <slot />
            </main>

            <!-- Footer -->
            <nav class="relative bottom-0 bg-blue-navbar flex text-white-snow z-[110] justify-start h-7 drop-shadow-xl-footer">
                <button id="footerbtn" type="button"
                    class="inline-flex items-center ml-3 sm:ml-4 md:ml-5 lg:ml-6 border-transparent text-xs leading-4 font-semibold text-white-snow">
                {{new Date().getFullYear()}} @ Datakorum Solutions S.L.
            </button>
        </nav>
    </div>
</div></template>

<script>
export default {

    data() {
        return {
            Alerts_badge: '0',
            ComponentVisibility: false,
            ComponentTitle: '',
            ComponentMessage: '',
            ComponentWidth: '',
        }
    },

    beforeMount(){

        this.$i18n.locale = localStorage.getItem("Language")

        window.emitter.on('AppLayout_alert', (status, title, message, width) => {
            this.ComponentVisibility = status;
            this.ComponentTitle = title;
            this.ComponentMessage = message;
            this.ComponentWidth = width;
        })
    },

    mounted(){

        setInterval(
            () => {
                this.Alerts_badge = localStorage.getItem("Alerts")
            },
            300 // 0.3 segundos
        )


    },

    methods: {

        getURL() {
            return window.location.href;
        },

        showComponent() {
            this.ComponentVisibility = true; // Mostrar el componente hijo
        },

        hideComponent() {
            this.ComponentVisibility = false; // Ocultar el componente hijo cuando se emite el evento 'close'
        },

    }

}
</script>

